fissix
======

Backport of latest lib2to3, with enhancements.

[![build status](https://travis-ci.org/jreese/fissix.svg?branch=master)](https://travis-ci.org/jreese/fissix)
[![version](https://img.shields.io/pypi/v/fissix.svg)](https://pypi.org/project/fissix)
[![license](https://img.shields.io/pypi/l/fissix.svg)](https://github.com/jreese/fissix/blob/master/LICENSE)
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)


License
-------

fissix is licensed under the Python Software Foundation License Version 2.
I am providing code in this repository to you under an open source license.
Because this is my personal repository, the license you receive to my code
is from me and not from my employer.
See the ``LICENSE`` file for details.
